aboutsummaryrefslogtreecommitdiffstats
path: root/installation
diff options
context:
space:
mode:
authorHector Anapan-Lavalle <ha076r@att.com>2017-10-24 19:13:22 -0400
committerHector Anapan-Lavalle <ha076r@att.com>2017-10-24 19:13:45 -0400
commit192f6bad7a24854defdb5c1a0f2a948ad87bcfd8 (patch)
treeb5921661e544d05ed4712630629943370dbf6917 /installation
parentbd863814f64653131d2cb05942e5ac61fa300399 (diff)
Handle dg-loader DGs approach with platform-logic
This commit takes care of adding the necessary code to be able to: 1) Convert JSON DGs to XML DGs in the dg-loader-dgs path 2) Load & Activate these converted XML DGs into the MySQL DB This approach is used in appc.git's dg-loader-provider to handle DGs. Combining platform-logic approach and dg-loader-provider approach to handle DGs coming from these two separate paths. Change-Id: I46505a3380afcdd3c6794e24fda75aef62ccc58f Signed-off-by: Hector Anapan-Lavalle <ha076r@att.com> Issue-Id:[APPC-287]
Diffstat (limited to 'installation')
-rw-r--r--installation/appc/src/main/scripts/startODL.sh20
1 files changed, 13 insertions, 7 deletions
diff --git a/installation/appc/src/main/scripts/startODL.sh b/installation/appc/src/main/scripts/startODL.sh
index 5ff7b32..7642820 100644
--- a/installation/appc/src/main/scripts/startODL.sh
+++ b/installation/appc/src/main/scripts/startODL.sh
@@ -22,8 +22,8 @@
###
#
# This script takes care of installing the SDN-C & APP-C platform components
# if not already installed, and starts the APP-C Docker Container
#
ODL_HOME=${ODL_HOME:-/opt/opendaylight/current}
@@ -64,9 +64,9 @@ echo -e "\nmysql ready"
if [ ! -f ${SDNC_HOME}/.installed ]
then
- echo "Installing SDN-C database"
+ echo "Installing SDNC database"
${SDNC_HOME}/bin/installSdncDb.sh
- echo "Installing APP-C database"
+ echo "Installing APPC database"
${APPC_HOME}/bin/installAppcDb.sh
echo "Starting OpenDaylight"
${ODL_HOME}/bin/start
@@ -75,7 +75,7 @@ then
echo "Inserting modified installFeatures.sh for sdnc"
rm ${SDNC_HOME}/bin/installFeatures.sh
cp ${APPC_HOME}/data/sdncInstallFeatures.sh ${SDNC_HOME}/bin/installFeatures.sh
- echo "Installing SDN-C platform features"
+ echo "Installing SDNC platform features"
${SDNC_HOME}/bin/installFeatures.sh
if [ -x ${SDNC_HOME}/svclogic/bin/install.sh ]
then
@@ -83,14 +83,20 @@ then
${SDNC_HOME}/svclogic/bin/install.sh
fi
- echo "Installing APP-C platform features"
+ echo "Installing APPC platform features"
${APPC_HOME}/bin/installFeatures.sh
if [ -x ${APPC_HOME}/svclogic/bin/install.sh ]
then
- echo "Installing directed graphs for APP-C"
+ echo "Installing APPC DGs using platform-logic"
${APPC_HOME}/svclogic/bin/install.sh
fi
+ if [ -x ${APPC_HOME}/svclogic/bin/install-converted-dgs.sh ]
+ then
+ echo "Installing APPC JSON DGs converted to XML using dg-loader"
+ ${APPC_HOME}/svclogic/bin/install-converted-dgs.sh
+ fi
+
echo "Restarting OpenDaylight"
${ODL_HOME}/bin/stop
echo "Installed at `date`" > ${SDNC_HOME}/.installed
@@ -22,8 +22,8 @@
###
#
-# This script takes care of installing the SDN-C & APP-C platform components
-# if not already installed, and starts the APP-C Docker Container
+# This script takes care of installing the SDNC & APPC platform components
+# if not already installed, and starts the APPC Docker Container
#
ODL_HOME=${ODL_HOME:-/opt/opendaylight/current}